<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="215"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="216"/>
      <source>Add tool</source>
      <translation>Lägg till verktyg</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="217"/>
      <source>Add a tool shape to the robot</source>
      <translation>Lägg till en verktygsform till roboten</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <source>Place robot...</source>
      <translation>Placera roboten ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="160"/>
      <source>Place a robot (experimental!)</source>
      <translation>Placera en robot (experimentell!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="62"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="63"/>
      <source>Create trajectory</source>
      <translation>Skapa bana</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="64"/>
      <source>Create a new empty trajectory </source>
      <translation>Skapa en ny tom bana </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="320"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="321"/>
      <source>Edge to Trajectory...</source>
      <translation>Kant till bana...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="322"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Generera en bana från en uppsättning med kanter</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="50"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="51"/>
      <source>Kuka compact subroutine...</source>
      <translation>KUKA kompakt subrutin ...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="52"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Exportera banan som en kompakt KRL subrutin.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location filename="../../CommandExport.cpp" line="112"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="113"/>
      <source>Kuka full subroutine...</source>
      <translation>fullständig KUKA subrutin ...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="114"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Exportera banan som en fullständig KRL subrutin.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="174"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="175"/>
      <source>Kuka IR125</source>
      <translation>KUKA IR125</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="176"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Sätt in en Kuka IR125 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="93"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="94"/>
      <source>Kuka IR16</source>
      <translation>KUKA IR16</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="95"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Sätt in en Kuka IR16 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="134"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="135"/>
      <source>Kuka IR210</source>
      <translation>KUKA IR210</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="136"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Sätt in en Kuka IR210 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="51"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="52"/>
      <source>Kuka IR500</source>
      <translation>KUKA IR500</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="53"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Sätt in en Kuka IR500 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="95"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="96"/>
      <source>Insert in trajectory</source>
      <translation>Sätt in i bana</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="97"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Infoga robotverktygets plats i banan</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="152"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="153"/>
      <source>Insert in trajectory</source>
      <translation>Sätt in i bana</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="154"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Infoga förvalsposition till banan (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <location filename="../../Command.cpp" line="106"/>
      <source>Move to home</source>
      <translation>Flytta till hemposition</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="216"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="217"/>
      <source>Set default orientation</source>
      <translation>Ange standard orientering</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="218"/>
      <source>Set the default orientation for subsequent commands for waypoint creation</source>
      <translation>Ange standardorienteringen för efterföljande kommandon vid skapande av banpunkter</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="254"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="255"/>
      <source>Set default values</source>
      <translation>Ange standardvärden</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="256"/>
      <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>Ange standardvärden för hastighet, acceleration och kontinuitet för efterföljande kommandon för banpunkter</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="56"/>
      <location filename="../../Command.cpp" line="57"/>
      <source>Set the home position</source>
      <translation>Ställ hemposition</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="200"/>
      <source>Simulate a trajectory</source>
      <translation>Simulera en bana</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="201"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Kör en simulering på en bana</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="431"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="432"/>
      <source>Trajectory compound...</source>
      <translation>Sammansatt bana...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="433"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Gruppera och anslut vissa banor till en</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="384"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="385"/>
      <source>Dress-up trajectory...</source>
      <translation>Bekläd färdbana...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="386"/>
      <source>Create a dress-up object which overrides some aspects of a trajectory</source>
      <translation>Skapa ett utklädnadsobjekt som åsidosätter vissa aspekter hos en färdbana</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="53"/>
      <source>Trajectory tools</source>
      <translation>Banverktyg</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="54"/>
      <source>Robot tools</source>
      <translation>Robot verktyg</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="55"/>
      <source>Insert Robot</source>
      <translation>Sätt in Robot</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="124"/>
      <location filename="../../Command.cpp" line="224"/>
      <location filename="../../Command.cpp" line="253"/>
      <location filename="../../CommandExport.cpp" line="65"/>
      <location filename="../../CommandExport.cpp" line="127"/>
      <location filename="../../CommandInsertRobot.cpp" line="234"/>
      <location filename="../../CommandTrajectory.cpp" line="111"/>
      <location filename="../../CommandTrajectory.cpp" line="167"/>
      <location filename="../../CommandTrajectory.cpp" line="184"/>
      <location filename="../../CommandTrajectory.cpp" line="412"/>
      <source>Wrong selection</source>
      <translation>Fel val</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Select one Robot to set home position</source>
      <translation>Välj en robot för att ställa in hempositionen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="125"/>
      <source>Select one Robot</source>
      <translation>Välj en Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <location filename="../../Command.cpp" line="254"/>
      <location filename="../../CommandExport.cpp" line="66"/>
      <location filename="../../CommandExport.cpp" line="128"/>
      <location filename="../../CommandTrajectory.cpp" line="112"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Välj en robot och ett banobjekt.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="230"/>
      <source>Trajectory not valid</source>
      <translation>Banan inte giltig</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="231"/>
      <source>You need at least two waypoints in a trajectory to simulate.</source>
      <translation>Du behöver minst två banpunkter i en bana för att simulera.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="88"/>
      <location filename="../../CommandExport.cpp" line="150"/>
      <source>KRL file</source>
      <translation>KRL fil</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="89"/>
      <location filename="../../CommandExport.cpp" line="151"/>
      <source>All Files</source>
      <translation>Alla Filer</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="90"/>
      <location filename="../../CommandExport.cpp" line="152"/>
      <source>Export program</source>
      <translation>Exportera programmet</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="235"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Välj en robot och en form eller ett VRML objekt.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="168"/>
      <location filename="../../CommandTrajectory.cpp" line="185"/>
      <source>Select one Trajectory object.</source>
      <translation>Välj ett banobjekt.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="191"/>
      <source>No preselection</source>
      <translation>Inga förval</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="192"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>Du måste sväva ovanför en geometri (Förval) med musen för att använda detta kommando. Se dokumentationen för detaljer.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="268"/>
      <source>Set default speed</source>
      <translation>Ange standardhastighet</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="269"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>hastighet: (t.ex. 1 m/s eller 3 cm/s)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="278"/>
      <source>Set default continuity</source>
      <translation>Ange standardkontinuitet</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="279"/>
      <source>continuous ?</source>
      <translation>Kontinuerlig?</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="285"/>
      <source>Set default acceleration</source>
      <translation>Ange standardacceleration</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="286"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>acceleration: (t.ex. 1 m/s^2 eller 3 cm/s^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="413"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Markera banan som du vill klä upp.</translation>
    </message>
    <message>
      <location filename="../../ViewProviderTrajectory.cpp" line="164"/>
      <source>Modify</source>
      <translation>Modifiera</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="81"/>
      <source>No robot files installed</source>
      <translation>Inga robotfiler installerade</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="82"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Besök %1 och kopiera filerna till %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="20"/>
      <source>Simulation</source>
      <translation>Simulering</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="272"/>
      <source>Type</source>
      <translation>Typ</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="277"/>
      <source>Name</source>
      <translation>Namn</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="282"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="287"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="292"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="47"/>
      <source>TaskEdge2TracParameter</source>
      <translation>TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="14"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="22"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="69"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="116"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="163"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="210"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="257"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="313"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="329"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Verktyg: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="345"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="52"/>
      <source>TaskRobot6Axis</source>
      <translation>Uppgift 6-axlad robot</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="46"/>
      <source>TaskRobotControl</source>
      <translation>Uppgift Robotkontroll</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="46"/>
      <source>TaskRobotMessages</source>
      <translation>Uppgift Robot meddelanden</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="20"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="254"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="259"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="264"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="269"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="274"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="291"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="317"/>
      <source>Type</source>
      <translation>Typ</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="322"/>
      <source>Name</source>
      <translation>Namn</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="327"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="332"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="337"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="44"/>
      <source>Trajectory</source>
      <translation>Rörelsebana</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="48"/>
      <source>Dress Up Parameter</source>
      <translation>Klä upp Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
      <source>Hide / Show</source>
      <translation>Dölj / Visa</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
      <source>Edges: 0</source>
      <translation>Kanter: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
      <source>Cluster: 0</source>
      <translation>Kluster: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
      <source>Sizing Value:</source>
      <translation>Storleksguide Värde:</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
      <source>Use orientation of edge</source>
      <translation>Använd orientering av kanten</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="14"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="37"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="56"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="75"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="94"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="113"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="132"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="151"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="170"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="189"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="208"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="227"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="246"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="258"/>
      <source>Tool 0</source>
      <translation>Verktyg 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="263"/>
      <source>Tool</source>
      <translation>Verktyg</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="268"/>
      <source>Base 0</source>
      <translation>Bas 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="273"/>
      <source>Base</source>
      <translation>Bas</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="278"/>
      <source>World</source>
      <translation>Värld</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="287"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="292"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="297"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="302"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0,5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="307"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0,1°</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="14"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="20"/>
      <source>clear</source>
      <translation>Rensa</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Hastighet &amp; Acceleration:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
      <source>Speed:</source>
      <translation>Hastighet:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
      <source>Use</source>
      <translation>Använd</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
      <source>Accel:</source>
      <translation>Acceleration:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
      <source>Don't change Cont</source>
      <translation>Ändra inte forts</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
      <source>Continues</source>
      <translation>Fortsätter</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
      <source>Discontinues</source>
      <translation>Upphör</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
      <source>Position and Orientation:</source>
      <translation>Position och orientering:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="136"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="149"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Ändra inte position och orientering</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
      <source>Use Orientation</source>
      <translation>Använd Orientering</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
      <source>Add Position</source>
      <translation>Lägg till position</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
      <source>Add Orientation</source>
      <translation>Lägg till Orientering</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="49"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="50"/>
      <source>Insert Robots</source>
      <translation>Infoga robotar</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="51"/>
      <source>&amp;Robot</source>
      <translation>&amp;Robot</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="52"/>
      <source>Export trajectory</source>
      <translation>Exportera bana</translation>
    </message>
  </context>
</TS>
